"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOpenApiSpec = void 0;
const fs = __importStar(require("fs"));
const yaml = __importStar(require("js-yaml"));
const path = __importStar(require("path"));
/**
 * Check if given file exists and try to read the content as string.
 * @param filePath
 */
function read(filePath) {
    if (fs.existsSync(filePath)) {
        try {
            return fs.readFileSync(filePath, 'utf8').toString();
        }
        catch (e) {
            throw new Error(`Could not read OpenApi spec: "${filePath}"`);
        }
    }
    throw new Error(`Could not find OpenApi spec: "${filePath}"`);
}
/**
 * Load and parse te open api spec. If the file extension is ".yml" or ".yaml"
 * we will try to parse the file as a YAML spec, otherwise we will fallback
 * on parsing the file as JSON.
 * @param input
 */
function getOpenApiSpec(input) {
    const file = path.resolve(process.cwd(), input);
    const extname = path.extname(file).toLowerCase();
    const content = read(file);
    switch (extname) {
        case '.yml':
        case '.yaml':
            try {
                return yaml.safeLoad(content);
            }
            catch (e) {
                throw new Error(`Could not parse OpenApi YAML: "${file}"`);
            }
        default:
            try {
                return JSON.parse(content);
            }
            catch (e) {
                throw new Error(`Could not parse OpenApi JSON: "${file}"`);
            }
    }
}
exports.getOpenApiSpec = getOpenApiSpec;
