"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postProcessServiceOperations = void 0;
const flatMap_1 = require("./flatMap");
const postProcessUnionTypes_1 = require("./postProcessUnionTypes");
function postProcessServiceOperations(service, client, useUnionTypes = false) {
    const names = new Map();
    return service.operations.map((operation) => {
        const clone = { ...operation };
        // Parse the service parameters and results, very similar to how we parse
        // properties of models. These methods will extend the type if needed.
        clone.parameters = clone.parameters.map((parameter) => postProcessUnionTypes_1.postProcessUnionTypes(parameter, client, useUnionTypes));
        clone.results = clone.results.map((result) => postProcessUnionTypes_1.postProcessUnionTypes(result, client, useUnionTypes));
        clone.imports.push(...flatMap_1.flatMap(clone.parameters, (parameter) => parameter.imports));
        clone.imports.push(...flatMap_1.flatMap(clone.results, (result) => result.imports));
        // Check of the operation name
        const name = clone.name;
        const index = names.get(name) || 0;
        if (index > 0) {
            clone.name = `${name}${index}`;
        }
        names.set(name, index + 1);
        return clone;
    });
}
exports.postProcessServiceOperations = postProcessServiceOperations;
