"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeClient = void 0;
const fs = __importStar(require("fs"));
const mkdirp = __importStar(require("mkdirp"));
const path = __importStar(require("path"));
const rimraf = __importStar(require("rimraf"));
const writeClientIndex_1 = require("./writeClientIndex");
const writeClientModels_1 = require("./writeClientModels");
const writeClientSchemas_1 = require("./writeClientSchemas");
const writeClientServices_1 = require("./writeClientServices");
const writeClientSettings_1 = require("./writeClientSettings");
function copySupportFile(filePath, outputPath) {
    fs.copyFileSync(path.resolve(__dirname, `../../src/templates/${filePath}`), path.resolve(outputPath, filePath));
}
/**
 * Write our OpenAPI client, using the given templates at the given output path.
 * @param client Client object with all the models, services, etc.
 * @param templates Templates wrapper with all loaded Handlebars templates.
 * @param output Directory to write the generated files to.
 * @param httpClient The selected httpClient (fetch or XHR).
 * @param useOptions Use options or arguments functions.
 * @param exportServices: Generate services.
 * @param exportSchemas: Generate schemas.
 */
function writeClient(client, templates, output, httpClient, useOptions, exportServices, exportSchemas) {
    const outputPath = path.resolve(process.cwd(), output);
    const outputPathCore = path.resolve(outputPath, 'core');
    const outputPathModels = path.resolve(outputPath, 'models');
    const outputPathSchemas = path.resolve(outputPath, 'schemas');
    const outputPathServices = path.resolve(outputPath, 'services');
    // Clean output directory
    rimraf.sync(outputPath);
    mkdirp.sync(outputPath);
    if (exportServices) {
        mkdirp.sync(outputPathCore);
        mkdirp.sync(outputPathServices);
        copySupportFile('core/ApiError.ts', outputPath);
        copySupportFile('core/getFormData.ts', outputPath);
        copySupportFile('core/getQueryString.ts', outputPath);
        copySupportFile('core/isSuccess.ts', outputPath);
        copySupportFile('core/OpenAPI.hbs', outputPath);
        copySupportFile('core/request.ts', outputPath);
        copySupportFile('core/RequestOptions.ts', outputPath);
        copySupportFile('core/requestUsingFetch.ts', outputPath);
        copySupportFile('core/requestUsingXHR.ts', outputPath);
        copySupportFile('core/Result.ts', outputPath);
        writeClientServices_1.writeClientServices(client.services, templates, outputPathServices, useOptions);
        writeClientSettings_1.writeClientSettings(client, templates, outputPathCore, httpClient);
    }
    if (exportSchemas) {
        mkdirp.sync(outputPathSchemas);
        writeClientSchemas_1.writeClientSchemas(client.models, templates, outputPathSchemas);
    }
    mkdirp.sync(outputPathModels);
    copySupportFile('models/Dictionary.ts', outputPath);
    writeClientModels_1.writeClientModels(client.models, templates, outputPathModels);
    writeClientIndex_1.writeClientIndex(client, templates, outputPath, exportServices, exportSchemas);
}
exports.writeClient = writeClient;
